@@ -7,7 +7,7 @@ use strict;
 use vars qw[$DEBUG $error $VERSION $WARN];
 $DEBUG      = 0;
 $WARN       = 1;
-$VERSION    = "0.99_04";
+$VERSION    = "0.99_05";
 
 use IO::File;
 use Cwd;
@@ -362,7 +362,7 @@ sub _extract_file {
     
     eval { File::Path::mkpath( $dir, 0, 0777 ) };
     if( $@ ) {
-        $self->_error( qq[Could not create directory 'dir': $@] );
+        $self->_error( qq[Could not create directory '$dir': $@] );
         return undef;
     }
     
